<?php

/**
 * The admin-settings specific functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    BrewPixel_Workable
 * @subpackage BrewPixel_Workable/admin
 */

/**
 * The admin-settings specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    BrewPixel_Workable
 * @subpackage BrewPixel_Workable/admin
 * @author     Martin Goldie <martin@brewpixel.com>
 */
class BrewPixel_Workable_Admin_Settings {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->register_plugin_settings();

	}

	/**
	 * Register the settings for the plugin.
	 */
	public function register_plugin_settings() {

		$api_settings_url = new \BrewPixel\BrewPress\AdminSetting\Setting(
			array(
				'id'    => 'plugin_workable_settings_section',
				'title' => 'API Settings',
				// 'callback'  => 'setting_section_callback',
				'page'  => 'brew-plugin-workable-settings',
				'args'  => '',
			),
			array(
				'id'    => 'bp_plugin_workable_setting_url',
				'label' => 'API URL',
				// 'callback'  => [ $this, 'setting_section_default_callback' ],
				'page'  => 'brew-plugin-workable-settings',
				'args'  => [
					"URL for API"
				],
			),
			'text'
		);

		$api_settings_token = new \BrewPixel\BrewPress\AdminSetting\Setting(
			array(
				'id'    => 'plugin_workable_settings_section',
				'title' => 'API Settings',
				// 'callback'  => 'setting_section_callback',
				'page'  => 'brew-plugin-workable-settings',
				'args'  => '',
			),
			array(
				'id'    => 'bp_plugin_workable_setting_token',
				'label' => 'Token',
				// 'callback'  => [ $this, 'setting_section_default_callback' ],
				'page'  => 'brew-plugin-workable-settings',
				'args'  => [
					"Token for API"
				],
			),
			'text'
		);

		$api_settings_token->create_plugin_page(
			array(
				'page_title' => 'BrewPixel Workable Plugin Settings',
				'menu_title' => 'Workable Plugin',
				'capability' => 'manage_options',
				'menu_slug'  => 'brew-plugin-workable-settings',
			)
		);

	}

}
