<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              http://example.com
 * @since             1.0.0
 * @package           BrewPixel_Workable
 *
 * @wordpress-plugin
 * Plugin Name:       BrewPixel Workable
 * Plugin URI:        http://brewpixel.com/
 * Description:       This plugin displays jobs from Workable via the API.
 * Version:           1.0.1
 * Author:            Martin Goldie @ BrewPixel
 * Author URI:        http://brewpixel.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       brewpixel-workable
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

add_action( 'plugins_loaded', 'run_plugin_name' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-brewpixel-workable-activator.php
 */
function activate_plugin_name() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-brewpixel-workable-activator.php';
	BrewPixel_Workable_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-brewpixel-workable-deactivator.php
 */
function deactivate_plugin_name() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-brewpixel-workable-deactivator.php';
	BrewPixel_Workable_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_plugin_name' );
register_deactivation_hook( __FILE__, 'deactivate_plugin_name' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-brewpixel-workable.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_plugin_name() {

	$plugin = new BrewPixel_Workable();
	$plugin->run();

}


/**
 * Check to make sure the BrewPress plugin has been installed and activated.
 */
function bp_workable_check_plugin_requirements() {
	if ( false === class_exists( '\BrewPixel\BrewPress\BrewPress' ) ) {
		require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		deactivate_plugins( plugin_basename( __FILE__ ) );
		$html = '<div class="error">';
		$html .= '<p>';
		$html .= __(
			'There was a problem activating the polecat.com bespoke plugin.',
			'brewpixel-bespoke'
		);
		$html .= '</p>';
		$html .= __(
			'This plugin requires that BrewPress plugin be activated. Please try again. Sorry about that.',
			'brewpixel-bespoke'
		);
		$html .= '</div><!-- /.updated -->';
		wp_die( wp_kses_post( $html ) );
	}
}

add_action( 'plugins_loaded', 'bp_bespoke_check_plugin_requirements' );
