<?php

/**
 * Created by IntelliJ IDEA.
 * User: goldie
 * Date: 18/02/2016
 * Time: 15:53
 */
class BrewPixel_Workable_API {
	/**
	 * @var
	 */
	public $jobs;

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	public $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	public $version;

	public function __construct( $plugin_name, $version, $jobs ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		$this->jobs = $this->request_jobs();
		$this->set_jobs( $this->jobs );

	}

	/**
	 *
	 */
	public function request_jobs( $url = '', $token = '' ) {
// {@see https://codex.wordpress.org/HTTP_API}
		$url_setting = get_option( 'bp_plugin_workable_setting_url' );
		$token_setting = get_option( 'bp_plugin_workable_setting_token' );
		$url = $url_setting.'jobs';
		$token = 'Bearer '.$token_setting;

		$response = wp_remote_get( $url, array(
			'headers' => array(
				'Authorization' => $token,
			),
		) );

		$body = '';
		if ( ! is_wp_error( $response ) ) {
			// The request went through successfully, check the response code against
			// what we're expecting

			if ( 200 == wp_remote_retrieve_response_code( $response ) ) {
				// Do something with the response
				$body = wp_remote_retrieve_body( $response );
				$headers = wp_remote_retrieve_headers( $response );
					$this->set_jobs( $body );
			} else {
				// The response code was not what we were expecting, record the message
				$error_message = wp_remote_retrieve_response_message( $response );
				echo $error_message;
			}
		} else {
			// There was an error making the request
			$error_message = $response->get_error_message();
			// return $error_message;
		}
		return $body;
	}

	/**
	 * @return mixed
	 */
	public function get_jobs() {
		if ( ! $this->jobs ) {
			$this->set_jobs( $this->request_jobs() );
		}
		return $this->jobs;
	}

	/**
	 * @param mixed $jobs
	 */
	public function set_jobs( $jobs ) {
		$this->jobs = $jobs;
	}

	public function show_jobs() {
		$workable = json_decode( $this->get_jobs() );

		if ( $workable && empty( $workable->jobs ) ) {
			echo '<h3 class="p-b-s p-t-s-1 d-text-style-2 d-text-size-s-1">';
			_e( 'There are currently no job postings', 'brewpixel-workable' );
			echo '</h3>';
		} else if ( $workable ) {
			foreach ( $workable->jobs as $job ) {

				$id              = $job->id;
				$title           = $job->title;
				$full_title      = $job->full_title;
				$shortcode       = $job->shortcode;
				$code            = $job->code;
				$state           = $job->state;
				$department      = $job->department;
				$url             = $job->url;
				$application_url = $job->application_url;
				$shortlink       = $job->shortlink;
				$location        = $job->location;
				$country         = $job->location->country;
				$country_code    = $job->location->country_code;
				$region          = $job->location->region;
				$region_code     = $job->location->region_code;
				$city            = $job->location->city;
				$zip_code        = $job->location->zip_code;
				$telecommuting   = $job->location->telecommuting;
				$created_at      = $job->created_at;


				/*
				  <li>ID: '.$id.'</li>
				  <li>Title: '.$title.'</li>
				  <li>Full title: '.$full_title.'</li>
				  <li>Shortcode: '.$shortcode.'</li>
				  <li>Code: '.$code.'</li>
				  <li>State: '.$state.'</li>
							<li>URL: '.$url.'</li>
				  <li>Application URL: '.$application_url.'</li>
				  <li>Shortlink: '.$shortlink.'</li>
				  <li>Country: '.$country.'</li>
				  <li>Country code: '.$country_code.'</li>
				  <li>Region: '.$region.'</li>
				  <li>Region code: '.$region_code.'</li>
				<li>Postal Code: '.$zip_code.'</li>
				  <li>Telecommuting: '.$telecommuting.'</li>
				  <li>Date Posted: '.$created_at.'</li>
				  */
				$remotework = '';


				if ( $telecommuting ) {
					$remotework = '<span class="bp-icon-computer icon-m-2 icon-left-0 d-text-size-s-0"></span> Telecommuting<span class="bp-icon-checkmark3 icon-right"></span>';
				}
				$buttontext = __( 'Details', 'brewpixel-workable' );
				$show_jobs  = '
				<h3 class="p-b-s p-t-s-1 d-text-style-2 d-text-size-s-1">' . $country . '</h3>
				<div class="l-grid-flex l-grid-flex--cols-2-mq-1024-up l-grid-flex--start l-grid-flex--gutters-m p-b-s-1">
					<div class="l-grid-flex__item l-col-100">
						<div class="careers-card">
							<h4 class="careers-card__title">' . $title . '</h4>
							<div class="careers-card__meta">
								<div class="careers-card__meta__description"><span>' . $department . '</span></div>
								<div class="careers-card__meta__location"><span>' . $city . '</span></div>
							</div>
							<div class="careers-card__footer">
								<div class="careers-card__footer__item">
									<div class="btn btn--2">
										<a href="' . $url . '">' . $buttontext . '</a>
									</div>
								</div>
								<div class="careers-card__footer__item">
									' . $remotework . '
								</div>
							</div>
						</div>
					</div>
				</div>
			';
				echo $show_jobs;
				$remotework = '';
			}
		}
	}
}
